@@ -74,7 +74,8 @@ def create(data, error=None, morph_params=True, x=None, y=None, obj_name=None, f
             with: df.to_csv('filename'). Defaults to True.
         path (str, optional): By default the text file containing the photometry will be
             saved to the local directory, unless an absolute path to a directory is entered here.
-        
+        filename(str, optional): Name of the output catalog. Default name is 'pyBIA_catalog'.
+
     Note:
         As Lyman-alpha nebulae are diffuse sources with
         extended emission features, the default radius of
@@ -107,8 +108,7 @@ def create(data, error=None, morph_params=True, x=None, y=None, obj_name=None, f
         if len(x) != len(y):
             raise ValueError("The two position arrays (x & y) must be the same size.")
     if invert == False:
-        warn('WARNING: Is your data from a .fits file? If so you may need to set invert=True if (x,y) = (0,0) \
-            is at the top left corner of the image instead of the bottom left corner.')
+        warn('WARNING: Is your data from a .fits file? If so you may need to set invert=True if (x,y) = (0,0) is at the top left corner of the image instead of the bottom left corner.')
     if x is None: #Apply DAOFIND (Stetson 1987) to detect sources in the image
         mean, median, std = sigma_clipped_stats(data, sigma=3.0)
         print('Performing source detection -- this will take several minutes...')
@@ -119,8 +119,8 @@ def create(data, error=None, morph_params=True, x=None, y=None, obj_name=None, f
         x, y = np.array(sources['xcentroid']), np.array(sources['ycentroid'])
 
     positions = []
-    for it in range(len(x)):
-        positions.append((x[it], y[it]))
+    for j in range(len(x)):
+        positions.append((x[j], y[j]))
 
     apertures = CircularAperture(positions, r=aperture)
     annulus_apertures = CircularAnnulus(positions, r_in=annulus_in, r_out=annulus_out)
@@ -207,6 +207,7 @@ def morph_parameters(data, x, y, invert=False, nsig=2):
         x, y = [x], [y]
 
     prop_list=[]
+    print('Applying image segmentation, this could take a while...')
     for i in range(len(x)):
         new_data = data_processing.crop_image(data, int(x[i]), int(y[i]), 100, invert=invert)
         threshold = detect_threshold(new_data, nsigma=nsig)
@@ -218,9 +219,8 @@ def morph_parameters(data, x, y, invert=False, nsig=2):
         try:
             props = SourceCatalog(new_data, segm, kernel=kernel)
         except:
-            warn('At least one object could not be detected in segmentation... perhaps too object is too faint \
-                or there is a coordinate error.')
-            props_list.append([0])
+            warn('At least one object could not be detected in segmentation... perhaps the object is too faint or there is a coordinate error. NOTE: This object is still in the catalog, the morphologcail features have been set to zero.')
+            prop_list.append(0)
             continue
 
         sep_list=[]
@@ -235,9 +235,9 @@ def morph_parameters(data, x, y, invert=False, nsig=2):
         if len(inx) > 1:
             inx = inx[0]
 
-        prop_list.append(props[int(inx)])
+        prop_list.append(props[inx])
 
-    return prop_list
+    return np.array(prop_list)
 
 def make_table(props):
     """
@@ -257,44 +257,44 @@ def make_table(props):
     for i in range(len(props)):
         prop_list = []
         try:
-            props[i].area
+            props[i][0].area
         except:
-            for xx in range(30):
-                prop_list.append([0])
+            for j in range(30): #number of morphological params
+                prop_list.append(0)
             table.append(prop_list)
             continue
 
-        prop_list.append(float(props[i].area / u.pix**2))
-        prop_list.append(props[i].bbox_xmax)
-        prop_list.append(props[i].bbox_xmin)
-        prop_list.append(props[i].bbox_ymax)
-        prop_list.append(props[i].bbox_ymin)
-        prop_list.append(props[i].bbox.shape[0] * props[i].bbox.shape[1])
-        prop_list.append(float(props[i].covar_sigx2 / u.pix**2))
-        prop_list.append(float(props[i].covar_sigxy / u.pix**2))
-        prop_list.append(float(props[i].covar_sigy2 / u.pix**2))
-        prop_list.append(float(props[i].covariance_eigvals[0] / u.pix**2))
-        prop_list.append(float(props[i].covariance_eigvals[1] / u.pix**2))
-        prop_list.append(float(props[i].cxx * u.pix**2))
-        prop_list.append(float(props[i].cxy * u.pix**2))
-        prop_list.append(float(props[i].cyy * u.pix**2))
-        prop_list.append(float(props[i].eccentricity))
-        prop_list.append(float(props[i].ellipticity))
-        prop_list.append(float(props[i].elongation))
-        prop_list.append(float(props[i].equivalent_radius / u.pix))
-        prop_list.append(float(props[i].fwhm / u.pix))
-        prop_list.append(props[i].gini)
-        prop_list.append(props[i].kron_flux)
-        prop_list.append(float(props[i].kron_radius / u.pix))
-        prop_list.append(props[i].max_value)
-        prop_list.append(props[i].min_value)
-        prop_list.append(float(props[i].orientation / u.degree))
-        prop_list.append(float(props[i].perimeter / u.pix))
-        prop_list.append(props[i].segment_flux)
-        prop_list.append(float(props[i].semimajor_sigma / u.pix))
-        prop_list.append(float(props[i].semiminor_sigma / u.pix))
+        prop_list.append(float(props[i][0].area / u.pix**2))
+        prop_list.append(props[i][0].bbox_xmax)
+        prop_list.append(props[i][0].bbox_xmin)
+        prop_list.append(props[i][0].bbox_ymax)
+        prop_list.append(props[i][0].bbox_ymin)
+        prop_list.append(props[i][0].bbox.shape[0] * props[i][0].bbox.shape[1])
+        prop_list.append(float(props[i][0].covar_sigx2 / u.pix**2))
+        prop_list.append(float(props[i][0].covar_sigxy / u.pix**2))
+        prop_list.append(float(props[i][0].covar_sigy2 / u.pix**2))
+        prop_list.append(float(props[i][0].covariance_eigvals[0] / u.pix**2))
+        prop_list.append(float(props[i][0].covariance_eigvals[1] / u.pix**2))
+        prop_list.append(float(props[i][0].cxx * u.pix**2))
+        prop_list.append(float(props[i][0].cxy * u.pix**2))
+        prop_list.append(float(props[i][0].cyy * u.pix**2))
+        prop_list.append(float(props[i][0].eccentricity))
+        prop_list.append(float(props[i][0].ellipticity))
+        prop_list.append(float(props[i][0].elongation))
+        prop_list.append(float(props[i][0].equivalent_radius / u.pix))
+        prop_list.append(float(props[i][0].fwhm / u.pix))
+        prop_list.append(props[i][0].gini)
+        prop_list.append(props[i][0].kron_flux)
+        prop_list.append(float(props[i][0].kron_radius / u.pix))
+        prop_list.append(props[i][0].max_value)
+        prop_list.append(props[i][0].min_value)
+        prop_list.append(float(props[i][0].orientation / u.degree))
+        prop_list.append(float(props[i][0].perimeter / u.pix))
+        prop_list.append(props[i][0].segment_flux)
+        prop_list.append(float(props[i][0].semimajor_sigma / u.pix))
+        prop_list.append(float(props[i][0].semiminor_sigma / u.pix))
 
-        if props[i].isscalar == True: #Checks whether it's a single source
+        if props[i][0].isscalar == True: #Checks whether it's a single source
             prop_list.append(1)
         else:
             prop_list.append(0)
@@ -302,8 +302,8 @@ def make_table(props):
 
     return np.array(table)
 
-def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=None,
-    field_name=None, flag=None, save=True, path=None):
+def make_dataframe(table=None, x=None, y=None, flux=None, flux_err=None, obj_name=None,
+    field_name=None, flag=None, save=True, path=None, filename=None):
     """
     This function takes as input the catalog of morphological features
     which is output by the make_cat_tbl function -- this catalog is converted
@@ -311,7 +311,8 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=Non
 
 
     Args:
-        table: Table containing the object features. Can make with make_table() function.
+        table (optional): Table containing the object features. Can make with make_table() function.
+            If None then a Pandas dataframe containing only the input columns will be generated. Defaults to None.
         x (ndarray, optional): 1D array containing the x-pixel position.
             If input it must be an array of x positions for all objects in the table. 
             This x position will be appended to the dataframe for cataloging purposes. Defaults to None.
@@ -330,6 +331,8 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=Non
             directory. Defaults to True. 
         path (str, optional): Absolute path where CSV file should be saved, if save=True. If 
             path is not set, the file will be saved to the local directory.
+        filename(str, optional): Name of the output catalog. Default name is 'pyBIA_catalog'.
+
 
     Note:
         These features can be used to create a machine learning model. 
@@ -346,6 +349,8 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=Non
         will be saved to the local directory, unless a path is specified.
 
     """
+    if filename is None:
+        filename = 'pyBIA_catalog'
 
     prop_list = ['area', 'bbox_xmax', 'bbox_xmin', 'bbox_ymax', 'bbox_ymin', 'bbox',
         'covar_sigx2', 'covar_sigxy', 'covar_sigy2', 'covariance_eigvals1', 'covariance_eigvals2',
@@ -374,7 +379,7 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=Non
         df = pd.DataFrame(data_dict)
         if save == True:
             if path is not None:
-                df.to_csv(filename) 
+                df.to_csv(path+filename) 
                 return df
             df.to_csv(filename)  
         return df
@@ -387,12 +392,12 @@ def make_dataframe(table, x=None, y=None, flux=None, flux_err=None, obj_name=Non
     for i in range(len(table[0])):
         data_dict[prop_list[i]] = table[:,i]
 
-    df = pd.DataFrame(data_dict, index=np.arange(0, len(table[:,0])))
+    df = pd.DataFrame(data_dict)
     if save == True:
         if path is not None:
-            df.to_csv(path+'pyBIA_catalog') 
+            df.to_csv(path+filename) 
             return df
-        df.to_csv('pyBIA_catalog')  
+        df.to_csv(filename)  
         return df
     return df
 
